@@ -51,15 +51,16 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--mandir=/usr/share/man' '--infodir=/usr/share/info' "
                 "'--datadir=/usr/share' '--sysconfdir=/etc' "
                 "'--localstatedir=/var/lib' '--datarootdir=/usr/share' "
-                "'--docdir=/usr/share/doc/python-3.12.2_p1' "
-                "'--htmldir=/usr/share/doc/python-3.12.2_p1/html' "
+                "'--docdir=/usr/share/doc/python-3.12.3-r1' "
+                "'--htmldir=/usr/share/doc/python-3.12.3-r1/html' "
                 "'--libdir=/usr/lib64' 'ac_cv_header_stropts_h=no' "
                 "'--enable-shared' '--without-static-libpython' "
                 "'--enable-ipv6' '--infodir=/usr/share/info' "
                 "'--mandir=/usr/share/man' '--with-computed-gotos' "
                 "'--with-dbmliborder=gdbm' '--with-libc=' "
                 "'--enable-loadable-sqlite-extensions' '--without-ensurepip' "
-                "'--without-lto' '--with-system-expat' '--with-platlibdir=lib' "
+                "'--without-lto' '--with-system-expat' "
+                "'--with-system-libmpdec' '--with-platlibdir=lib' "
                 "'--with-pkg-config=yes' "
                 "'--with-wheel-pkg-dir=/usr/lib/python/ensurepip' "
                 "'--without-assertions' '--disable-optimizations' "
@@ -71,9 +72,9 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.12',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/var/tmp/portage/dev-lang/python-3.12.2_p1/work/Python-3.12.2/coverage.info',
+ 'COVERAGE_INFO': '/var/tmp/portage/dev-lang/python-3.12.3-r1/work/Python-3.12.3/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/var/tmp/portage/dev-lang/python-3.12.2_p1/work/Python-3.12.2/lcov-report',
+ 'COVERAGE_REPORT': '/var/tmp/portage/dev-lang/python-3.12.3-r1/work/Python-3.12.3/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.12 LCOV report [commit $(shell '
                             ')]"',
@@ -664,11 +665,11 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBHACL_SHA2_OBJS': '\\',
  'LIBM': '-lm',
  'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
- 'LIBMPDEC_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_64=1 -DANSI=1 '
-                    '-DHAVE_UINT128_T=1 -fno-strict-overflow -Wsign-compare '
-                    '-DNDEBUG -O2 -pipe -fwrapv -std=c11 -Wextra '
-                    '-Wno-unused-parameter -Wno-missing-field-initializers '
-                    '-Wstrict-prototypes -Werror=implicit-function-declaration '
+ 'LIBMPDEC_CFLAGS': '-DCONFIG_64=1 -DANSI=1 -DHAVE_UINT128_T=1 '
+                    '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 -pipe '
+                    '-fwrapv -std=c11 -Wextra -Wno-unused-parameter '
+                    '-Wno-missing-field-initializers -Wstrict-prototypes '
+                    '-Werror=implicit-function-declaration '
                     '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
                     '-I/usr/include/ncursesw -fPIC -fPIC',
  'LIBMPDEC_HEADERS': '\\',
@@ -885,11 +886,9 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__DBM_CFLAGS': '-DUSE_GDBM_COMPAT',
  'MODULE__DBM_LDFLAGS': '-lgdbm_compat',
  'MODULE__DBM_STATE': 'yes',
- 'MODULE__DECIMAL_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_64=1 '
-                           '-DANSI=1 -DHAVE_UINT128_T=1',
- 'MODULE__DECIMAL_DEPS': './Modules/_decimal/docstrings.h \\ '
-                         'Modules/_decimal/libmpdec/libmpdec.a',
- 'MODULE__DECIMAL_LDFLAGS': '-lm Modules/_decimal/libmpdec/libmpdec.a',
+ 'MODULE__DECIMAL_CFLAGS': '-DCONFIG_64=1 -DANSI=1 -DHAVE_UINT128_T=1',
+ 'MODULE__DECIMAL_DEPS': './Modules/_decimal/docstrings.h',
+ 'MODULE__DECIMAL_LDFLAGS': '-lmpdec',
  'MODULE__DECIMAL_STATE': 'yes',
  'MODULE__ELEMENTTREE_CFLAGS': '',
  'MODULE__ELEMENTTREE_DEPS': './Modules/pyexpat.c',
@@ -1082,7 +1081,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': '@READELF@',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.2_p1/work/Python-3.12.2',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.3-r1/work/Python-3.12.3',
  'SCRIPTDIR': '/usr/lib',
  'SCRIPT_2TO3': 'build/scripts-3.12/2to3-3.12',
  'SCRIPT_IDLE': 'build/scripts-3.12/idle3.12',
@@ -1206,10 +1205,10 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.2_p1/work/Python-3.12.2 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.3-r1/work/Python-3.12.3 '
                './python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.2_p1/work/Python-3.12.2 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.3-r1/work/Python-3.12.3 '
                './python -E ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'idlelib/idle_test \\',
  'TESTTIMEOUT': 1200,
@@ -1239,8 +1238,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/var/tmp/portage/dev-lang/python-3.12.2_p1/work/Python-3.12.2',
- 'abs_srcdir': '/var/tmp/portage/dev-lang/python-3.12.2_p1/work/Python-3.12.2',
+ 'abs_builddir': '/var/tmp/portage/dev-lang/python-3.12.3-r1/work/Python-3.12.3',
+ 'abs_srcdir': '/var/tmp/portage/dev-lang/python-3.12.3-r1/work/Python-3.12.3',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
