@@ -28,7 +28,6 @@ build_time_vars = {'ABIFLAGS': '',
  'CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
- 'CFLAGS_NODIST': '',
  'CODECS_COMMON_HEADERS': './Modules/cjkcodecs/multibytecodec.h '
                           './Modules/cjkcodecs/cjkcodecs.h',
  'COMPILEALL_OPTS': '-j24',
@@ -37,7 +36,8 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGURE_CFLAGS': '',
  'CONFIGURE_CFLAGS_NODIST': '-O3 -pipe -march=znver2 -mtune=znver3 '
                             '-frecord-gcc-switches -fdiagnostics-color=never '
-                            '-fwrapv -std=c11 -Wextra -Wno-unused-parameter '
+                            '-fwrapv -fno-semantic-interposition -std=c11 '
+                            '-Wextra -Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Wstrict-prototypes '
                             '-Werror=implicit-function-declaration '
@@ -47,36 +47,43 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGURE_LDFLAGS_NODIST': '-v -Wl,-O1 -Wl,--as-needed '
                              '-Wl,-z,pack-relative-relocs -Wl,-O2 '
                              '-Wl,--as-needed -Wl,-z,pack-relative-relocs '
-                             '-Wl,-z,relro -Wl,-z,now',
+                             '-Wl,-z,relro -Wl,-z,now '
+                             '-fno-semantic-interposition',
  'CONFIGURE_LDFLAGS_NOLTO': '',
  'CONFIG_ARGS': "'--prefix=/usr' '--build=x86_64-pc-linux-gnu' "
                 "'--host=x86_64-pc-linux-gnu' '--mandir=/usr/share/man' "
                 "'--infodir=/usr/share/info' '--datadir=/usr/share' "
                 "'--sysconfdir=/etc' '--localstatedir=/var/lib' "
                 "'--datarootdir=/usr/share' "
-                "'--docdir=/usr/share/doc/python-3.12.1_p1' "
-                "'--htmldir=/usr/share/doc/python-3.12.1_p1/html' "
+                "'--docdir=/usr/share/doc/python-3.12.3-r1' "
+                "'--htmldir=/usr/share/doc/python-3.12.3-r1/html' "
                 "'--libdir=/usr/lib64' 'ac_cv_header_stropts_h=no' "
                 "'--enable-shared' '--without-static-libpython' "
                 "'--enable-ipv6' '--infodir=/usr/share/info' "
                 "'--mandir=/usr/share/man' '--with-computed-gotos' "
                 "'--with-dbmliborder=gdbm' '--with-libc=' "
                 "'--enable-loadable-sqlite-extensions' '--without-ensurepip' "
-                "'--without-lto' '--with-system-expat' '--with-platlibdir=lib' "
+                "'--without-lto' '--with-system-expat' "
+                "'--with-system-libmpdec' '--with-platlibdir=lib' "
                 "'--with-pkg-config=yes' "
                 "'--with-wheel-pkg-dir=/usr/lib/python/ensurepip' "
-                "'--without-assertions' '--disable-optimizations' "
+                "'--without-assertions' '--enable-optimizations' "
                 "'--with-readline=readline' '--without-valgrind' "
                 "'build_alias=x86_64-pc-linux-gnu' "
                 "'host_alias=x86_64-pc-linux-gnu' "
                 "'PKG_CONFIG=x86_64-pc-linux-gnu-pkg-config' 'CFLAGS=' "
-                "'LDFLAGS=' 'CPPFLAGS= -I/usr/include/ncursesw'",
+                "'LDFLAGS=' 'CPPFLAGS= -I/usr/include/ncursesw' "
+                "'PROFILE_TASK=-m test -j24 --pgo-extended -u-network "
+                '--timeout 1200 -x test_gdb -x test_dtrace -x test_asyncio -x '
+                'test_concurrent_futures -x test_httpservers -x test_logging '
+                '-x test_multiprocessing_fork -x test_socket -x test_xmlrpc -x '
+                "test_tools'",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.12',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/var/tmp/portage/dev-lang/python-3.12.1_p1/work/Python-3.12.1/coverage.info',
+ 'COVERAGE_INFO': '/var/tmp/portage/dev-lang/python-3.12.3-r1/work/Python-3.12.3/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/var/tmp/portage/dev-lang/python-3.12.1_p1/work/Python-3.12.1/lcov-report',
+ 'COVERAGE_REPORT': '/var/tmp/portage/dev-lang/python-3.12.3-r1/work/Python-3.12.3/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.12 LCOV report [commit $(shell '
                             ')]"',
@@ -627,22 +634,21 @@ build_time_vars = {'ABIFLAGS': '',
                    '/usr/include/python3.12',
  'INCLUDEDIR': '/usr/include',
  'INCLUDEPY': '/usr/include/python3.12',
- 'INSTALL': '/var/tmp/portage/._portage_reinstall_.r5btukhx/bin/ebuild-helpers/xattr/install '
+ 'INSTALL': '/var/tmp/portage/._portage_reinstall_.tyf2cp7v/bin/ebuild-helpers/xattr/install '
             '-c',
- 'INSTALL_DATA': '/var/tmp/portage/._portage_reinstall_.r5btukhx/bin/ebuild-helpers/xattr/install '
+ 'INSTALL_DATA': '/var/tmp/portage/._portage_reinstall_.tyf2cp7v/bin/ebuild-helpers/xattr/install '
                  '-c -m 644',
- 'INSTALL_PROGRAM': '/var/tmp/portage/._portage_reinstall_.r5btukhx/bin/ebuild-helpers/xattr/install '
+ 'INSTALL_PROGRAM': '/var/tmp/portage/._portage_reinstall_.tyf2cp7v/bin/ebuild-helpers/xattr/install '
                     '-c',
- 'INSTALL_SCRIPT': '/var/tmp/portage/._portage_reinstall_.r5btukhx/bin/ebuild-helpers/xattr/install '
+ 'INSTALL_SCRIPT': '/var/tmp/portage/._portage_reinstall_.tyf2cp7v/bin/ebuild-helpers/xattr/install '
                    '-c',
- 'INSTALL_SHARED': '/var/tmp/portage/._portage_reinstall_.r5btukhx/bin/ebuild-helpers/xattr/install '
+ 'INSTALL_SHARED': '/var/tmp/portage/._portage_reinstall_.tyf2cp7v/bin/ebuild-helpers/xattr/install '
                    '-c -m 755',
  'INSTSONAME': 'libpython3.12.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'x86_64-pc-linux-gnu-g++ -shared',
  'LDFLAGS': '',
- 'LDFLAGS_NODIST': '',
  'LDLIBRARY': 'libpython3.12.so',
  'LDLIBRARYDIR': '',
  'LDSHARED': 'x86_64-pc-linux-gnu-gcc -shared',
@@ -653,20 +659,24 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
  'LIBEXPAT_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O3 -pipe '
                     '-march=znver2 -mtune=znver3 -frecord-gcc-switches '
-                    '-fdiagnostics-color=never -fwrapv -std=c11 -Wextra '
+                    '-fdiagnostics-color=never -fwrapv '
+                    '-fno-semantic-interposition -std=c11 -Wextra '
                     '-Wno-unused-parameter -Wno-missing-field-initializers '
                     '-Wstrict-prototypes -Werror=implicit-function-declaration '
-                    '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
+                    '-fvisibility=hidden -fprofile-use -fprofile-correction '
+                    '-I./Include/internal -I. -I./Include '
                     '-I/usr/include/ncursesw -fPIC -fPIC',
  'LIBEXPAT_HEADERS': '\\',
  'LIBEXPAT_OBJS': '\\',
  'LIBHACL_CFLAGS': '-I./Modules/_hacl/include -D_BSD_SOURCE -D_DEFAULT_SOURCE '
                    '-fno-strict-overflow -Wsign-compare -DNDEBUG -O3 -pipe '
                    '-march=znver2 -mtune=znver3 -frecord-gcc-switches '
-                   '-fdiagnostics-color=never -fwrapv -std=c11 -Wextra '
+                   '-fdiagnostics-color=never -fwrapv '
+                   '-fno-semantic-interposition -std=c11 -Wextra '
                    '-Wno-unused-parameter -Wno-missing-field-initializers '
                    '-Wstrict-prototypes -Werror=implicit-function-declaration '
-                   '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
+                   '-fvisibility=hidden -fprofile-use -fprofile-correction '
+                   '-I./Include/internal -I. -I./Include '
                    '-I/usr/include/ncursesw -fPIC -fPIC',
  'LIBHACL_HEADERS': '\\',
  'LIBHACL_SHA2_A': 'Modules/_hacl/libHacl_Hash_SHA2.a',
@@ -674,14 +684,15 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBHACL_SHA2_OBJS': '\\',
  'LIBM': '-lm',
  'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
- 'LIBMPDEC_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_64=1 -DANSI=1 '
-                    '-DHAVE_UINT128_T=1 -fno-strict-overflow -Wsign-compare '
-                    '-DNDEBUG -O3 -pipe -march=znver2 -mtune=znver3 '
-                    '-frecord-gcc-switches -fdiagnostics-color=never -fwrapv '
-                    '-std=c11 -Wextra -Wno-unused-parameter '
-                    '-Wno-missing-field-initializers -Wstrict-prototypes '
-                    '-Werror=implicit-function-declaration '
-                    '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
+ 'LIBMPDEC_CFLAGS': '-DCONFIG_64=1 -DANSI=1 -DHAVE_UINT128_T=1 '
+                    '-fno-strict-overflow -Wsign-compare -DNDEBUG -O3 -pipe '
+                    '-march=znver2 -mtune=znver3 -frecord-gcc-switches '
+                    '-fdiagnostics-color=never -fwrapv '
+                    '-fno-semantic-interposition -std=c11 -Wextra '
+                    '-Wno-unused-parameter -Wno-missing-field-initializers '
+                    '-Wstrict-prototypes -Werror=implicit-function-declaration '
+                    '-fvisibility=hidden -fprofile-use -fprofile-correction '
+                    '-I./Include/internal -I. -I./Include '
                     '-I/usr/include/ncursesw -fPIC -fPIC',
  'LIBMPDEC_HEADERS': '\\',
  'LIBMPDEC_OBJS': '\\',
@@ -895,11 +906,9 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__DBM_CFLAGS': '-DUSE_GDBM_COMPAT',
  'MODULE__DBM_LDFLAGS': '-lgdbm_compat',
  'MODULE__DBM_STATE': 'yes',
- 'MODULE__DECIMAL_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_64=1 '
-                           '-DANSI=1 -DHAVE_UINT128_T=1',
- 'MODULE__DECIMAL_DEPS': './Modules/_decimal/docstrings.h \\ '
-                         'Modules/_decimal/libmpdec/libmpdec.a',
- 'MODULE__DECIMAL_LDFLAGS': '-lm Modules/_decimal/libmpdec/libmpdec.a',
+ 'MODULE__DECIMAL_CFLAGS': '-DCONFIG_64=1 -DANSI=1 -DHAVE_UINT128_T=1',
+ 'MODULE__DECIMAL_DEPS': './Modules/_decimal/docstrings.h',
+ 'MODULE__DECIMAL_LDFLAGS': '-lmpdec',
  'MODULE__DECIMAL_STATE': 'yes',
  'MODULE__ELEMENTTREE_CFLAGS': '',
  'MODULE__ELEMENTTREE_DEPS': './Modules/pyexpat.c',
@@ -1024,7 +1033,11 @@ build_time_vars = {'ABIFLAGS': '',
  'PLATLIBDIR': 'lib',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
- 'PROFILE_TASK': '-m test --pgo --timeout=1200',
+ 'PROFILE_TASK': '-m test -j24 --pgo-extended -u-network --timeout 1200 -x '
+                 'test_gdb -x test_dtrace -x test_asyncio -x '
+                 'test_concurrent_futures -x test_httpservers -x test_logging '
+                 '-x test_multiprocessing_fork -x test_socket -x test_xmlrpc '
+                 '-x test_tools',
  'PTHREAD_KEY_T_IS_COMPATIBLE_WITH_INT': 1,
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PURIFY': '',
@@ -1046,38 +1059,44 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_BUILTIN_MODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O3 '
                              '-pipe -march=znver2 -mtune=znver3 '
                              '-frecord-gcc-switches -fdiagnostics-color=never '
-                             '-fwrapv -std=c11 -Wextra -Wno-unused-parameter '
+                             '-fwrapv -fno-semantic-interposition -std=c11 '
+                             '-Wextra -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Wstrict-prototypes '
                              '-Werror=implicit-function-declaration '
-                             '-fvisibility=hidden  -I./Include/internal -I. '
+                             '-fvisibility=hidden -fprofile-use '
+                             '-fprofile-correction -I./Include/internal -I. '
                              '-I./Include -I/usr/include/ncursesw -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG',
  'PY_CFLAGS_NODIST': '-O3 -pipe -march=znver2 -mtune=znver3 '
                      '-frecord-gcc-switches -fdiagnostics-color=never -fwrapv '
-                     '-std=c11 -Wextra -Wno-unused-parameter '
-                     '-Wno-missing-field-initializers -Wstrict-prototypes '
+                     '-fno-semantic-interposition -std=c11 -Wextra '
+                     '-Wno-unused-parameter -Wno-missing-field-initializers '
+                     '-Wstrict-prototypes '
                      '-Werror=implicit-function-declaration '
-                     '-fvisibility=hidden  -I./Include/internal',
+                     '-fvisibility=hidden -fprofile-use -fprofile-correction '
+                     '-I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O3 -pipe '
                    '-march=znver2 -mtune=znver3 -frecord-gcc-switches '
-                   '-fdiagnostics-color=never -fwrapv -std=c11 -Wextra '
+                   '-fdiagnostics-color=never -fwrapv '
+                   '-fno-semantic-interposition -std=c11 -Wextra '
                    '-Wno-unused-parameter -Wno-missing-field-initializers '
                    '-Wstrict-prototypes -Werror=implicit-function-declaration '
-                   '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
+                   '-fvisibility=hidden -fprofile-use -fprofile-correction '
+                   '-I./Include/internal -I. -I./Include '
                    '-I/usr/include/ncursesw -fPIC -DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-v -Wl,-O1 -Wl,--as-needed -Wl,-z,pack-relative-relocs '
                     '-Wl,-O2 -Wl,--as-needed -Wl,-z,pack-relative-relocs '
-                    '-Wl,-z,relro -Wl,-z,now',
+                    '-Wl,-z,relro -Wl,-z,now -fno-semantic-interposition',
  'PY_CPPFLAGS': '-I. -I./Include -I/usr/include/ncursesw',
  'PY_ENABLE_SHARED': 1,
  'PY_HAVE_PERF_TRAMPOLINE': 1,
  'PY_LDFLAGS': '',
  'PY_LDFLAGS_NODIST': '-v -Wl,-O1 -Wl,--as-needed -Wl,-z,pack-relative-relocs '
                       '-Wl,-O2 -Wl,--as-needed -Wl,-z,pack-relative-relocs '
-                      '-Wl,-z,relro -Wl,-z,now',
+                      '-Wl,-z,relro -Wl,-z,now -fno-semantic-interposition',
  'PY_LDFLAGS_NOLTO': '',
  'PY_SQLITE_ENABLE_LOAD_EXTENSION': 1,
  'PY_SQLITE_HAVE_SERIALIZE': 1,
@@ -1086,10 +1105,12 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_STDMODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O3 '
                         '-pipe -march=znver2 -mtune=znver3 '
                         '-frecord-gcc-switches -fdiagnostics-color=never '
-                        '-fwrapv -std=c11 -Wextra -Wno-unused-parameter '
-                        '-Wno-missing-field-initializers -Wstrict-prototypes '
+                        '-fwrapv -fno-semantic-interposition -std=c11 -Wextra '
+                        '-Wno-unused-parameter -Wno-missing-field-initializers '
+                        '-Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
-                        '-fvisibility=hidden  -I./Include/internal -I. '
+                        '-fvisibility=hidden -fprofile-use '
+                        '-fprofile-correction -I./Include/internal -I. '
                         '-I./Include -I/usr/include/ncursesw -fPIC',
  'PY_SUPPORT_TIER': 1,
  'Py_DEBUG': 0,
@@ -1102,7 +1123,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': '@READELF@',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.1_p1/work/Python-3.12.1',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.3-r1/work/Python-3.12.3',
  'SCRIPTDIR': '/usr/lib',
  'SCRIPT_2TO3': 'build/scripts-3.12/2to3-3.12',
  'SCRIPT_IDLE': 'build/scripts-3.12/idle3.12',
@@ -1226,10 +1247,10 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.1_p1/work/Python-3.12.1 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.3-r1/work/Python-3.12.3 '
                './python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.1_p1/work/Python-3.12.1 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.3-r1/work/Python-3.12.3 '
                './python -E ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'idlelib/idle_test \\',
  'TESTTIMEOUT': 1200,
@@ -1259,8 +1280,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/var/tmp/portage/dev-lang/python-3.12.1_p1/work/Python-3.12.1',
- 'abs_srcdir': '/var/tmp/portage/dev-lang/python-3.12.1_p1/work/Python-3.12.1',
+ 'abs_builddir': '/var/tmp/portage/dev-lang/python-3.12.3-r1/work/Python-3.12.3',
+ 'abs_srcdir': '/var/tmp/portage/dev-lang/python-3.12.3-r1/work/Python-3.12.3',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
